==> haskell-network-bsd-2.8.1.0-310.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-network-bsd.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-bsd
version:              2.8.1.0
visibility:           public
id:                   network-bsd-2.8.1.0-tw2oRH0FuUAjhgeHdG5Oa
key:                  network-bsd-2.8.1.0-tw2oRH0FuUAjhgeHdG5Oa
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto, Herbert Valerio Riedel
homepage:             https://github.com/haskell/network-bsd
synopsis:             POSIX network database (<netdb.h>) API
description:
    This package provides Haskell bindings to the
    the [POSIX network database (<netdb.h>) API](http://pubs.opengroup.org/onlinepubs/009696699/basedefs/netdb.h.html).

    === Relationship to the @network@ package

    The @network@ package version 2.* series provides "Network.BSD" but
    it is removed starting with @network@ version 3.0.

    This package provides the "Network.BSD" module split off from the
    <https://hackage.haskell.org/package/network network package>.

    If in addition to the @network@'\''s modules also "Network.BSD" is
    necessary, add @network-bsd@ to your dependencies like so:

    > library
    >     build-depends: network     >= 2.7 && < 3.1
    >                  , network-bsd >= 2.7 && < 2.9

    I.e. you can control the version of the @network@ package
    independently.

    __NOTE__: Starting with @network-bsd-2.8.1.0@ the APIs of @network@
    and @network-bsd@ evolve differently, and consequently the
    versioning doesn'\''t match up anymore! Moreover, also starting with
    version @network-bsd-2.8.1.0@ this package requires @network >= 3@
    in order to avoid module name clashes with @network < 3@'\''s
    "Network.BSD" module.

    However, @network-bsd-2.7.0.0@ and @network-bsd-2.8.0.0@ passes thru
    the "Network.BSD" module from @network-2.7.*@ and @network-2.8.*@
    respectively in a non-clashing way via Cabal'\''s
    <https://www.haskell.org/cabal/users-guide/developing-packages.html#pkg-field-library-reexported-modules reexported-modules>
    feature while ensuring a well-defined
    <https://pvp.haskell.org/ API versioning> of the observable API of
    @network-bsd@. This is why the example above supporting a wide range
    of @network@ versions works by including version 2.7.0.0 in the
    required version range of @network-bsd@.

category:             Network
abi:                  15b8c5f786dcd2df96406ee1a796a280
exposed:              True
exposed-modules:      Network.BSD
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-bsd-2.8.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-bsd-2.8.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-bsd-2.8.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-bsd
hs-libraries:         HSnetwork-bsd-2.8.1.0-tw2oRH0FuUAjhgeHdG5Oa
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe

haddock-interfaces:   /usr/share/doc/haskell-network-bsd/html/network-bsd.haddock
haddock-html:         /usr/share/doc/haskell-network-bsd/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-bsd-2.8.1.0-311-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-network-bsd.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-bsd
version:              2.8.1.0
visibility:           public
id:                   network-bsd-2.8.1.0-D7anFlGqSCnK99qTn3SolU
key:                  network-bsd-2.8.1.0-D7anFlGqSCnK99qTn3SolU
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto, Herbert Valerio Riedel
homepage:             https://github.com/haskell/network-bsd
synopsis:             POSIX network database (<netdb.h>) API
description:
    This package provides Haskell bindings to the
    the [POSIX network database (<netdb.h>) API](http://pubs.opengroup.org/onlinepubs/009696699/basedefs/netdb.h.html).

    === Relationship to the @network@ package

    The @network@ package version 2.* series provides "Network.BSD" but
    it is removed starting with @network@ version 3.0.

    This package provides the "Network.BSD" module split off from the
    <https://hackage.haskell.org/package/network network package>.

    If in addition to the @network@'\''s modules also "Network.BSD" is
    necessary, add @network-bsd@ to your dependencies like so:

    > library
    >     build-depends: network     >= 2.7 && < 3.1
    >                  , network-bsd >= 2.7 && < 2.9

    I.e. you can control the version of the @network@ package
    independently.

    __NOTE__: Starting with @network-bsd-2.8.1.0@ the APIs of @network@
    and @network-bsd@ evolve differently, and consequently the
    versioning doesn'\''t match up anymore! Moreover, also starting with
    version @network-bsd-2.8.1.0@ this package requires @network >= 3@
    in order to avoid module name clashes with @network < 3@'\''s
    "Network.BSD" module.

    However, @network-bsd-2.7.0.0@ and @network-bsd-2.8.0.0@ passes thru
    the "Network.BSD" module from @network-2.7.*@ and @network-2.8.*@
    respectively in a non-clashing way via Cabal'\''s
    <https://www.haskell.org/cabal/users-guide/developing-packages.html#pkg-field-library-reexported-modules reexported-modules>
    feature while ensuring a well-defined
    <https://pvp.haskell.org/ API versioning> of the observable API of
    @network-bsd@. This is why the example above supporting a wide range
    of @network@ versions works by including version 2.7.0.0 in the
    required version range of @network-bsd@.

category:             Network
abi:                  5f2e6be7fffd487f57ca607e513e6eca
exposed:              True
exposed-modules:      Network.BSD
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-bsd-2.8.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-bsd-2.8.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-bsd-2.8.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-bsd
hs-libraries:         HSnetwork-bsd-2.8.1.0-D7anFlGqSCnK99qTn3SolU
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ

haddock-interfaces:   /usr/share/doc/haskell-network-bsd/html/network-bsd.haddock
haddock-html:         /usr/share/doc/haskell-network-bsd/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
